@@ -20,7 +20,7 @@ class Graph(Control):
     def get_state(self):
         state_str = ""
         for key in self.line_dict.keys():
-            state_str += self._state_str + key + self.line_dict[key].get_line_data()
+            state_str += self._control_hdr_str + key + self.line_dict[key].get_line_data()
         return state_str
 
     def __init__(
@@ -58,7 +58,7 @@ class Graph(Control):
     def send_graph(self):
         state_str = ""
         for key in self.line_dict.keys():
-            state_str += self._state_str + key + self.line_dict[key].get_line_data()
+            state_str += self._control_hdr_str + key + self.line_dict[key].get_line_data()
         self.state_str = state_str
 
     @property
